==> dwf-deploy-2.4.0.tgz: package/lib/dwf/object/type/txt.js <==
'use strict'

const coAbstractLib = require('./abstract.js')
const coLoggerLib = require('../../../logger.js')
const coValidateLib = require('../../validate.js')

const Result = require('../../result.js').Result

const csExt4Txt = '.txt'
const csExt4DlmTableGroup = '.dwfdlmtablegroup'
const csExt4DwfNdso = '.dwfndso'

module.exports.csExt4Txt = csExt4Txt
module.exports.csExt4DlmTableGroup = csExt4DlmTableGroup
module.exports.csExt4DwfNdso = csExt4DwfNdso

module.exports.createInstance = function (isExtension) {
  const coType = {}
  coType[coAbstractLib.csExtention] = isExtension
  coType[coAbstractLib.cfIsDeployable] = function () {
    let fCreate = coType[coAbstractLib.cfCreateTasks]
    if (fCreate) {
      return true
    } else {
      return false
    }
  }
  coType[coAbstractLib.cfPrepare] = function (iasFile, ioOption) {
    coValidateLib(iasFile.length, 'number')
    coValidateLib(ioOption, 'object')

    let loResult = new Result()
    let lsExt = coType[coAbstractLib.csExtention]
    iasFile.forEach(function (isFile) {
      let lsFile = isFile

      coLoggerLib.trace(' * ' + lsExt + ' - ' + lsFile + ' ... ')

      let loItem = {}
      loItem[coAbstractLib.csKey_AOI_nStatus] = coAbstractLib.cnSuccess
      loItem[coAbstractLib.csKey_AOI_sFile] = lsFile
      loItem[coAbstractLib.csKey_AOI_sDescription] = ''
      loResult.addItem(lsExt, loItem)

      coLoggerLib.log(' * ' + lsExt + ' - ' + lsFile + ' ... ok')
    })
    return loResult
  }
  coType[coAbstractLib.cfCreateTasks] = undefined

  return coType
}

==> dwf-deploy-2.6.6.tgz: package/lib/dwf/object/type/txt.js <==
'use strict'

const coAbstractLib = require('./abstract.js')
const coLoggerLib = require('../../../logger.js')
const coValidateLib = require('../../validate.js')

const Result = require('../../result.js').Result

const csExt4Txt = '.txt'
const csExt4DlmTableGroup = '.dwfdlmtablegroup'
const csExt4DwfNdso = '.dwfndso'

module.exports.csExt4Txt = csExt4Txt
module.exports.csExt4DlmTableGroup = csExt4DlmTableGroup
module.exports.csExt4DwfNdso = csExt4DwfNdso

module.exports.createInstance = function (isExtension) {
  const coType = {}
  coType[coAbstractLib.csExtention] = isExtension
  coType[coAbstractLib.cfIsDeployable] = function () {
    const fCreate = coType[coAbstractLib.cfCreateTasks]
    if (fCreate) {
      return true
    } else {
      return false
    }
  }
  coType[coAbstractLib.cfPrepare] = function (iasFile, ioOption) {
    coValidateLib(iasFile.length, 'number')
    coValidateLib(ioOption, 'object')

    const loResult = new Result()
    const lsExt = coType[coAbstractLib.csExtention]
    iasFile.forEach(function (isFile) {
      const lsFile = isFile

      coLoggerLib.trace(' * ' + lsExt + ' - ' + lsFile + ' ... ')

      const loItem = {}
      loItem[coAbstractLib.csKey_AOI_nStatus] = coAbstractLib.cnSuccess
      loItem[coAbstractLib.csKey_AOI_sFile] = lsFile
      loItem[coAbstractLib.csKey_AOI_sDescription] = ''
      loResult.addItem(lsExt, loItem)

      coLoggerLib.log(' * ' + lsExt + ' - ' + lsFile + ' ... ok')
    })
    return loResult
  }
  coType[coAbstractLib.cfCreateTasks] = undefined

  return coType
}
